@@ -1,9 +1,8 @@
 package Net::SAML2::IdP;
 use Moose;
 
-our $VERSION = '0.73'; # VERSION
+our $VERSION = '0.74'; # VERSION
 
-use MooseX::Types::URI qw/ Uri /;
 
 # ABSTRACT: SAML Identity Provider object
 
@@ -12,8 +11,10 @@ use Crypt::OpenSSL::Verify;
 use Crypt::OpenSSL::X509;
 use HTTP::Request::Common;
 use LWP::UserAgent;
-use XML::LibXML;
+use MooseX::Types::URI qw/ Uri /;
 use Try::Tiny;
+use XML::LibXML::XPathContext;
+
 use Net::SAML2::XML::Util qw/ no_comments /;
 
 
@@ -272,7 +273,7 @@ Net::SAML2::IdP - SAML Identity Provider object
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
